==> centreon-web-23.10.29.tar.gz: centreon-web-23.10.29/www/front_src/src/Dashboards/translatedLabels.tsx <==
export const labelDashboardLibrary = 'Dashboard library';
export const labelCreateADashboard = 'Create a dashboard';
export const labelWelcomeToDashboardInterface =
  'Welcome to the Dashboards interface!';
export const labelCancel = 'Cancel';
export const labelCreate = 'Create';
export const labelUpdate = 'Update';
export const labelDelete = 'Delete';
export const labelName = 'Name';
export const labelDescription = 'Description';
export const labelCreateDashboard = 'Create dashboard';
export const labelUpdateDashboard = 'Update dashboard';
export const labelDeleteDashboard = 'Delete dashboard';
export const labelDescriptionDeleteDashboard =
  'Are you sure you want to delete <strong>{{name}}</strong> ?';

export const labelDashboardCreated = 'Dashboard created';
export const labelDashboardUpdated = 'Dashboard updated';
export const labelDashboardDeleted = 'Dashboard deleted';
export const labelFailedToCreateDashboard = 'Failed to create the dashboard';
export const labelFailedToUpdateDashboard = 'Failed to update the dashboard';
export const labelFailedToDeleteDashboard = 'Failed to delete the dashboard';
export const labelShareTheDashboard = 'Share the dashboard';

export const labelEditAccessRights = 'Manage access rights';
export const labelCopyLinkToDashboard = 'Copy link';
export const labelCopyLinkToDashboardSuccess = 'Link copied';
export const labelCopyLinkToDashboardError = 'Unable to copy the link';
export const labelAdd = 'Add';
export const labelContactGroupTag = 'group';
export const labelContactNoOptionsText = 'No contacts found';
export const labelContactPlaceholder = 'Add Contact...';
export const labelAccessRightsListEmptyState = 'No access rights';
export const labelAccessRightStateAdded = 'added';
export const labelAccessRightStateRemoved = 'removed';
export const labelAccessRightStateUpdated = 'updated';
export const labelAccessRightsStatsAdded = 'added';
export const labelAccessRightsStatsRemoved = 'removed';
export const labelAccessRightsStatsUpdated = 'updated';

export const labelViewer = 'Viewer';
export const labelEditor = 'Editor';
export const labelFailedToCopyLink = 'Failed to copy link';
export const labelCopyLink = 'Copy link';
export const labelLinkCopied = 'Link copied';
export const labelSave = 'Save';
export const labelAddAContact = 'Add a contact';
export const labelAddAContactGroup = 'Add a contact group';
export const labelContact = 'Contact';
export const labelContactGroup = 'Contact group';
export const labelShareWith = 'Share with';
export const labelAdded = 'Added';
export const labelUpdated = 'Updated';
export const labelRemoved = 'Removed';
export const labelUserRights = 'User rights';
export const labelGroup = 'Group';
export const labelTheShareListIsEmpty = 'The share list is empty';
export const labelFailedToSaveShares = 'Failed to save shares';
export const labelSharesSaved = 'Shares saved';
export const labelDeleteUser = 'Delete user';
export const labelYouAreGoingToDeleteUser =
  'You are going to delete <strong>{{name}}</strong> from the user list. This user will no longer access the dashboard.';
export const labelUserDeleted = 'User deleted';

==> centreon-web-24.04.20.tar.gz: centreon-web-24.04.20/www/front_src/src/Dashboards/translatedLabels.tsx <==
export const labelDashboards = 'Dashboards';
export const labelCreateADashboard = 'Create a dashboard';
export const labelWelcomeToDashboardInterface =
  'Welcome to the Dashboards interface!';
export const labelCancel = 'Cancel';
export const labelCreate = 'Create';
export const labelUpdate = 'Update';
export const labelDelete = 'Delete';
export const labelDuplicate = 'Duplicate';
export const labelName = 'Name';
export const labelDescription = 'Description';
export const labelCreateDashboard = 'Create dashboard';
export const labelUpdateDashboard = 'Update dashboard';
export const labelDeleteDashboard = 'Delete dashboard';
export const labelDuplicateDashboard = 'Duplicate dashboard';
export const labelDescriptionDeleteDashboard =
  'The {{name}} dashboard will be permanently deleted.';
export const labelDashboardCreated = 'Dashboard created';
export const labelDashboardUpdated = 'Dashboard updated';
export const labelDashboardDeleted = 'Dashboard deleted';
export const labelDashboardDuplicated = 'Dashboard duplicated';
export const labelFailedToCreateDashboard = 'Failed to create the dashboard';
export const labelFailedToUpdateDashboard = 'Failed to update the dashboard';
export const labelFailedToDeleteDashboard = 'Failed to delete the dashboard';
export const labelFailedToDuplicateDashboard =
  'Failed to duplicate the dashboard';
export const labelShareTheDashboard = 'Share the dashboard';

export const labelEditAccessRights = 'Manage access rights';
export const labelCopyLinkToDashboard = 'Copy link';
export const labelCopyLinkToDashboardSuccess = 'Link copied';
export const labelCopyLinkToDashboardError = 'Unable to copy the link';
export const labelAdd = 'Add';
export const labelContactGroupTag = 'group';
export const labelContactNoOptionsText = 'No contacts found';
export const labelContactPlaceholder = 'Add Contact...';
export const labelAccessRightsListEmptyState = 'No access rights';
export const labelAccessRightStateAdded = 'added';
export const labelAccessRightStateRemoved = 'removed';
export const labelAccessRightStateUpdated = 'updated';
export const labelAccessRightsStatsAdded = 'added';
export const labelAccessRightsStatsRemoved = 'removed';
export const labelAccessRightsStatsUpdated = 'updated';

export const labelViewer = 'Viewer';
export const labelEditor = 'Editor';
export const labelFailedToCopyLink = 'Failed to copy link';
export const labelCopyLink = 'Copy link';
export const labelLinkCopied = 'Link copied';
export const labelSave = 'Save';
export const labelAddAContact = 'Add a contact';
export const labelAddAContactGroup = 'Add a contact group';
export const labelContact = 'Contact';
export const labelContactGroup = 'Contact group';
export const labelShareWith = 'Share with';
export const labelAdded = 'Added';
export const labelUpdated = 'Updated';
export const labelRemoved = 'Removed';
export const labelUserRights = 'User rights';
export const labelGroup = 'Group';
export const labelTheShareListIsEmpty = 'The share list is empty';
export const labelFailedToSaveShares = 'Failed to save shares';
export const labelSharesSaved = 'Shares saved';
export const labelDeleteUser = 'Delete user';
export const labelYouAreGoingToDeleteUser =
  'You are going to delete <strong>{{name}}</strong> from the user list. This user will no longer access the dashboard.';
export const labelUserDeleted = 'User deleted';
export const labelShareWithContacts = 'Share with contacts';
